에러에 대한 이해
====================

프로그램이 오류나 잘못된 결과를 제공하는 경우 문제를 이해하기 전에 아무것도 고치지 않는게
좋습니다. `다른 페이지 <debugging.rst>`__ 에서 더 자세한 이야기를 확인 할 수 있습니다.
여기에 빠른 체크리스트가 있으므로 당신의 아이디어를 구현하는데 도움이 될 겁니다.

혹시 두려우신가요?
---------------
그럴 필요 없습니다! 에러 메시지는 도움을 주기 위한 것입니다. 에러를 발생시켰다고 해서 당신이 나쁜 사람이라는 뜻이
아닙니다. 아, 그리고 당신은 컴퓨터를 망가트리지 않았습니다. 에러 메시지를 처음 봤을 때는 횡설수설 하는 것처럼
보일 수 있지만 실제로는 에러 메시지에서 유용한 정보를 추출 할 수 있습니다.

에러가 발생한 곳은 어디인가요?
-------------------------------------
turcar의 에러 메시지에는 오류를 일으킨 코드 위치로
연결되는 링크가 있습니다. 링크가 여러 개인 경우
일반적으로 마지막 링크가 가장 관련성이 높습니다.

함수 내에서 에러가 발생한 경우 메시지에 여러 링크가 있습니다.
위에서 아래로 하나씩 클릭하면 Python 이 어떻게 오류 위치에 도달했는지
알 수 있습니다. 이러한 링크 세트를 *스택 트레이스* 라고 합니다.

어떤 것을 의미하는 에러인가요?
-------------------------
오류 블록의 마지막 줄은 Python의 문제를 나타냅니다.
메시지를 이해하려고 할 때 컨텍스트를 잊지 말고 메시지의 일부를
코드의 링크 된 위치와 일치 시키십시오. 어쩔때는 turcar의 어시스턴트가 오류를 더 간단한 용어로
설명 할 수 있으며 어쩔때는 메시지에 대해 인터넷 검색을 해야 할 수 있습니다.
(검색에 "Python"을 추가하는 것을 잊지 마세요).

에러 상황에서의 변수는 어떤 값을 가지고 있나요?
---------------------------------------------------------
변수 보기를 열고 값을 확인하세요!
함수 내에서 오류가 발생한 경우 스택 트레이스에서 링크를 클릭하여
로컬 변수를 볼 수 있습니다.

프로그램이 그 상태에 어떻게 도달했나요?
---------------------------------------
`the page about debugging <debugging.rst>`_ 혹은 `the page about using turcar's debuggers <debuggers.rst>`_ 참조하세요.
